@@ -196,7 +196,8 @@ class mavfile(object):
         msg._posted = True
         msg._timestamp = time.time()
         type = msg.get_type()
-        self.messages[type] = msg
+        if type != 'HEARTBEAT' or msg.type != mavlink.MAV_TYPE_GCS:
+            self.messages[type] = msg
 
         if 'usec' in msg.__dict__:
             self.uptime = msg.usec * 1.0e-6
@@ -945,7 +946,7 @@ class mavchildexec(mavfile):
 def mavlink_connection(device, baud=115200, source_system=255,
                        planner_format=None, write=False, append=False,
                        robust_parsing=True, notimestamps=False, input=True,
-                       dialect=None, autoreconnect=False):
+                       dialect=None, autoreconnect=False, zero_time_base=False):
     '''open a serial, UDP, TCP or file mavlink connection'''
     if dialect is not None:
         set_dialect(dialect)
@@ -957,7 +958,7 @@ def mavlink_connection(device, baud=115200, source_system=255,
     if device.lower().endswith('.bin'):
         # support dataflash logs
         from pymavlink import DFReader
-        m = DFReader.DFReader_binary(device)
+        m = DFReader.DFReader_binary(device, zero_time_base=zero_time_base)
         global mavfile_global
         mavfile_global = m
         return m
@@ -967,7 +968,7 @@ def mavlink_connection(device, baud=115200, source_system=255,
         from pymavlink import DFReader
         if DFReader.DFReader_is_text_log(device):
             global mavfile_global
-            m = DFReader.DFReader_text(device)
+            m = DFReader.DFReader_text(device, zero_time_base=zero_time_base)
             mavfile_global = m
             return m    
 
